==> apache-calcite-1.36.0-src.tar.gz: apache-calcite-1.36.0-src/testkit/src/main/java/org/apache/calcite/test/ConnectionSpec.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.test;

import com.google.errorprone.annotations.Immutable;

/** Information necessary to create a JDBC connection.
 *
 * <p>Specify one to run tests against a different database. */
@Immutable
public class ConnectionSpec {
  public final String url;
  public final String username;
  public final String password;
  public final String driver;
  public final String schema;
  public final String catalog;

  public ConnectionSpec(String url, String username, String password,
      String driver, String schema) {
    this.url = url;
    this.username = username;
    this.password = password;
    this.driver = driver;
    this.schema = schema;
    this.catalog = null;
  }
}

==> apache-calcite-1.41.0-src.tar.gz: apache-calcite-1.41.0-src/testkit/src/main/java/org/apache/calcite/test/ConnectionSpec.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.test;

import com.google.errorprone.annotations.Immutable;

import org.checkerframework.checker.nullness.qual.Nullable;

/** Information necessary to create a JDBC connection.
 *
 * <p>Specify one to run tests against a different database. */
@Immutable
public class ConnectionSpec {
  public final String url;
  public final String username;
  public final String password;
  public final String driver;
  public final String schema;
  public final @Nullable String catalog;

  public ConnectionSpec(String url, String username, String password,
      String driver, String schema) {
    this.url = url;
    this.username = username;
    this.password = password;
    this.driver = driver;
    this.schema = schema;
    this.catalog = null;
  }
}
